# qe-tools
This repository contains a set of useful tools for Quantum ESPRESSO, in particular

 * a parser for pw.x input files
 * a parser for cp.x input files

The code is developed and maintained by the AiiDA Team and is licensed under the MIT license (see LICENSE file).

## Why isn't this part of AiiDA?

The intention of this repository is to provide tools for Quantum Espresso that do not require AiiDA to work.
Both the [aiida-quantumespresso plugin](https://github.com/aiidateam/aiida-quantumespresso) and AiiDA-agnostic software like [seekpath](https://github.com/giovannipizzi/seekpath) will build upon qe-tools.


